# Copyright (c) 2024, NVIDIA CORPORATION.  All rights reserved.
from megatron.core.inference.sampling_params import (  # noqa: F401 # pylint: disable=unused-import
    SamplingParams as CommonInferenceParams,
)
